@@ -13,7 +13,7 @@ class EchoMod : public SWText {
 public:
 	EchoMod();
 	virtual ~EchoMod();
-	virtual operator char*();
+	virtual operator const char*();
 };
 
 
