@@ -7,7 +7,7 @@
 #include <map>
 
 
-//using namespace std;
+using namespace std;
 
 
 typedef map <string, string, less <string> > ConfigEntMap;
