@@ -11,7 +11,8 @@
 #include <swtext.h>
 //---------------------------------------------------------------------------
 
-#define	defRTFHeader          "{\\rtf1\\ansi{\\fonttbl{\\f0\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f1\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f2\\froman\\fcharset2\\fprq2 Symbol;}{\\f3\\froman\\fcharset2\\fprq2 Symbol;}}{\\colortbl;\\red0\\green0\\blue255;\\red0\\green200\\blue50;\\red0\\green0\\blue255;\\red0\\green200\\blue50;\\red0\\green0\\blue255;\\red255\\green0\\blue0;} {\\fs8\\cf1\\par\\pard} "
+#define	defRTFHeader          "{\\rtf1\\ansi{\\fonttbl{\\f0\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f1\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f2\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f3\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f4\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f7\\froman\\fcharset2\\fprq2 Symbol;}{\\f8\\froman\\fcharset2\\fprq2 Symbol;}}{\\colortbl;\\red0\\green0\\blue255;\\red0\\green200\\blue50;\\red0\\green0\\blue255;\\red0\\green200\\blue50;\\red0\\green0\\blue255;\\red255\\green0\\blue0;} "
+#define	defRTFHeadMargin	  "{\\fs8\\cf1\\par\\pard} "
 #define	defRTFTrailer         "{\\fs24 \\par }}"
 
 #define	defRTFChapterMarkPre  "\\pard \\qc\\nowidctlpar{\\f1\\fs30\\b Chapter "
@@ -28,6 +29,7 @@ class SWDispRTF : public TRichEdit {
 protected:
 
 		System::AnsiString FRTFHeader;
+		System::AnsiString FRTFHeadMargin;
 		System::AnsiString FRTFTrailer;
 		System::AnsiString FRTFChapterMarkPre;
 		System::AnsiString FRTFChapterMarkPost;
@@ -35,6 +37,7 @@ protected:
 		System::AnsiString FRTFVerseMarkPost;
 		System::AnsiString FRTFVersePre;
 		System::AnsiString FRTFVersePost;
+		bool FExpandNewLine;
 		CHARRANGE FCharRange;
 		
 		int __fastcall GetMySelStart();
@@ -50,6 +53,7 @@ public:
 	virtual char Display(SWModule &imodule);
 __published:
 		__property System::AnsiString RTFHeader          = {read=FRTFHeader,           write=FRTFHeader};
+		__property System::AnsiString RTFHeadMargin      = {read=FRTFHeadMargin,       write=FRTFHeadMargin};
 		__property System::AnsiString RTFChapterMarkPre  = {read=FRTFChapterMarkPre,   write=FRTFChapterMarkPre};
 		__property System::AnsiString RTFChapterMarkPost = {read=FRTFChapterMarkPost,  write=FRTFChapterMarkPost};
 		__property System::AnsiString RTFVerseMarkPre    = {read=FRTFVerseMarkPre,     write=FRTFVerseMarkPre};
@@ -57,6 +61,7 @@ __published:
 		__property System::AnsiString RTFVersePre        = {read=FRTFVersePre,         write=FRTFVersePre};
 		__property System::AnsiString RTFVersePost       = {read=FRTFVersePost,        write=FRTFVersePost};
 		__property System::AnsiString RTFTrailer         = {read=FRTFTrailer,          write=FRTFTrailer};
+		__property bool               ExpandNewLine      = {read=FExpandNewLine,       write=FExpandNewLine};
 };
 //---------------------------------------------------------------------------
 #endif
