@@ -9,7 +9,7 @@
 #include <vcl\ComCtrls.hpp>
 #include <vcl\StdCtrls.hpp>
 #include <swtext.h>
-#include "swdisprtf.h"
+#include <swdisprtf.h>
 //---------------------------------------------------------------------------
 
 class SWDispRTFChap : public SWDispRTF {
