@@ -39,14 +39,14 @@ public:
 
 	virtual char Error();
 	virtual SWKey &operator =(const char *ikey);
-	virtual SWKey &operator =(SWKey &ikey);
-	virtual operator const char*();
+	virtual SWKey &operator =(const SWKey &ikey);
+	virtual operator const char*() const;
 
-	virtual char operator ==(SWKey &ikey);
-	virtual char operator  >(SWKey &ikey);
-	virtual char operator  <(SWKey &ikey);
-	virtual char operator >=(SWKey &ikey) { return ((*this > ikey) || (*this == ikey)); }
-	virtual char operator <=(SWKey &ikey) { return ((*this < ikey) || (*this == ikey)); }
+	virtual bool operator ==(const SWKey &ikey);
+	virtual bool operator  >(const SWKey &ikey);
+	virtual bool operator  <(const SWKey &ikey);
+	virtual bool operator >=(const SWKey &ikey) { return ((*this > ikey) || (*this == ikey)); }
+	virtual bool operator <=(const SWKey &ikey) { return ((*this < ikey) || (*this == ikey)); }
 	virtual SWKey &operator =(POSITION);
 	virtual SWKey &operator -=(int);
 	virtual SWKey &operator +=(int);
