@@ -26,7 +26,7 @@ public:
 	virtual SWListKey &operator <<(SWKey &); // add to list
 	virtual SWListKey &operator =(SWListKey &ikey);
 	virtual SWKey &operator =(const char *ikey){ return SWKey::operator =(ikey); }
-	virtual SWKey &operator =(SWKey &ikey){ return SWKey::operator =(ikey); }
+	virtual SWKey &operator =(const SWKey &ikey){ return SWKey::operator =(ikey); }
 	virtual SWKey &operator =(POSITION);
 	virtual SWKey &operator -=(int decrement);
 	virtual SWKey &operator +=(int increment);
