@@ -8,18 +8,34 @@
 #include <Forms.hpp>
 #include <Db.hpp>
 #include <DBTables.hpp>
+#include <versekey.h>
+#include <ExtCtrls.hpp>
 //---------------------------------------------------------------------------
 class TForm1 : public TForm
 {
 __published:	// IDE-managed Components
 	TDataSource *DataSource1;
 	TTable *Table1;
+	TListBox *ListBox1;
+	TPanel *Panel1;
 	TButton *Button1;
 	TEdit *Edit1;
 	void __fastcall Button1Click(TObject *Sender);
 private:	// User declarations
 public:		// User declarations
 	__fastcall TForm1(TComponent* Owner);
+VerseKey key1, key2, key3;
+int fp, vfp, cfp, bfp;
+long chapoffset;
+short chapsize;
+char testmnt;
+char startflag;
+void writeidx(VerseKey &key1, VerseKey &key2, VerseKey &key3, long offset, short size);
+VerseKey inckey;
+char findbreak(int fp, long *offset, int *num1, int *num2, int *rangemax, short *size, TTable *table1);
+void openfiles();
+void checkparams(int argc, char **argv);
+void charsetconvert(char *data);
 };
 //---------------------------------------------------------------------------
 extern PACKAGE TForm1 *Form1;
